#include	<stdarg.h>
#include	<string.h>
#include	"tss-ints.h"

/** \brief	-   "" 
 *
 *	       
 *       . 
 *     Big-endian  
 * ,  ,    .
 *
 */
class TssRawReader abstract {
public:
	/** \brief	    8- 
	 *
	 *	     8- ,  
	 *  Big-endian  .
	 *
	 * @param	value	   ,  
	 *
	 * @return			8- 
	 *
	 * \sa		TssRawReader
	 */
	static rtsp_uint8	get_int8( const void * value );

	/** \brief	    16- 
	 *
	 *	     16- ,  
	 *  Big-endian  .
	 *
	 * @param	value	   ,  
	 *
	 * @return			16- 
	 *
	 * \sa		TssRawReader
	 */
	static rtsp_uint16	get_int16( const void * value );

	/** \brief	    32- 
	 *
	 *	     32- ,  
	 *  Big-endian  .
	 *
	 * @param	value	   ,  
	 *
	 * @return			32- 
	 *
	 * \sa		TssRawReader
	 */
	static rtsp_uint32	get_int32( const void * value );

	/** \brief	    64- 
	 *
	 *	     64- ,  
	 *  Big-endian  .
	 *
	 * @param	value	   ,  
	 *
	 * @return			64- 
	 *
	 * \sa		TssRawReader
	 */
	static rtsp_uint64	get_int64( const void * value );

	/** \brief	    32-  
	 *
	 *	     32-  ,
	 *    Big-endian  .
	 *
	 * @param	value	   ,  
	 *
	 * @return			32-  
	 *
	 * \sa		TssRawReader
	 */
	static rtsp_real32	get_real32( const void * value );

	/** \brief	    64-  
	 *
	 *	     64-  ,
	 *    Big-endian  .
	 *
	 * @param	value	   ,  
	 *
	 * @return			64-  
	 *
	 * \sa		TssRawReader
	 */
	static rtsp_real64	get_real64( const void * value );

	/** \brief	     
	 *
	 *	      ,  
	 *  Big-endian  .
	 *
	 * @param	value	   ,  
	 *
	 * @return			 
	 *
	 * \sa		TssRawReader
	 */
	static bool		get_bool( const void * value );

	/** \brief	    US-ASCII
	 *
	 *	      US-ASCII.
	 *
	 * @param	value	  
	 *
	 * @return			 
	 *
	 * @attention	    ,     
	 *				     .
	 *
	 * \sa		TssRawReader
	 */
	static const char*	get_ascii( const void * value );
};

/** \brief	-     
 *
 *	    :    
 *      .
 *
 */
class TssOptionsHelper abstract {

public:
	/**	\brief	      .
	 *
	 *          . 
	 *    ,    
	 * ,   .
	 *
	 * @param	_where		   
	 * @param	_what		   
	 *
	 * @return				  ,   
	 *						   -1,     
	 *
	 * \sa		TssOptionsHelper
	 */
	static
	size_t		find_opt( const TssParamImport * _where , const char * _what );

	/**	\brief	     
	 *
	 *	          
	 *        .   
	 *       ,  - .
	 *
	 * @param	_where		   
	 * @param	_what		   
	 *
	 * @return				,     ,   .
	 *
	 * \sa		TssOptionsHelper
	 */
	static
	bool		exists( const TssParamImport * _where , const char * _what );

	/** \brief	  
	 *
	 *	      .  
	 *          , 
	 *     .      
	 *   (   ),    
	 *   .     
	 *  .
	 *
	 *	     ,   
	 *    .
	 *
	 * @param	full	    ,   
	 *					    .
	 * @param	opts	      .
	 * @return			    
	 *
	 * \sa		TssOptionsHelper
	 */
	static
	TssParamImport*	mk_options( const TssParamImport * full , va_list opts );

	/** \brief	   
	 *
	 *	      .  
	 *          , 
	 *     .      
	 *   (   ),    
	 *   .     
	 *  .
	 *
	 *	     ,   
	 *    .
	 *
	 * @param	full	    ,   
	 *					    .
	 * @return			    
	 *
	 * \sa		TssOptionsHelper
	 */
	static
	TssParamImport*	mk_options( const TssParamImport * full , ... );
};

